import React, { forwardRef, useEffect, useImperativeHandle, useState, } from 'react';
import { ActivityIndicator, Dimensions, FlatList, RefreshControl, View, } from 'react-native';
import { gDp } from 'th_comm.rn';
import EmptyView from '../empty-view/EmptyView';
import ErrorView, { ErrorType } from '../error-view/ErrorView';
function GJListView(props, ref) {
    // noinspection JSSuspiciousNameCombination
    var height = Dimensions.get('window').width;
    var _a = props.showInitLoading, showInitLoading = _a === void 0 ? true : _a, _b = props.canRefresh, canRefresh = _b === void 0 ? false : _b;
    var _c = props.size, size = _c === void 0 ? 10 : _c, _d = props.emptyConfig, emptyConfig = _d === void 0 ? { hint: '数据为空' } : _d, _e = props.dividerHeight, dividerHeight = _e === void 0 ? 0 : _e;
    var _f = useState(undefined), data = _f[0], setData = _f[1];
    // how many page that got.
    var _g = useState(0), page = _g[0], setPage = _g[1];
    // 是否正在数据，防重复加载
    var _h = useState(false), isLoadingData = _h[0], setIsLoadingData = _h[1];
    var _j = useState(false), showError = _j[0], setShowError = _j[1];
    var _k = useState(ErrorType.SERVER), errorType = _k[0], setErrorType = _k[1];
    var _l = useState(false), showLoading = _l[0], setShowLoading = _l[1];
    var _m = useState(true), isFirstTimeLoadData = _m[0], setIsFirstTimeLoadData = _m[1];
    var _o = useState(false), noMoreData = _o[0], setNoMoreData = _o[1];
    var dataIsEmpty = data && data.length === 0;
    var buildEmpty = function () {
        var _a;
        if (emptyConfig.builder) {
            return <emptyConfig.builder />;
        }
        else {
            return <EmptyView desc={(_a = emptyConfig === null || emptyConfig === void 0 ? void 0 : emptyConfig.hint) !== null && _a !== void 0 ? _a : ''}/>;
        }
    };
    var loadData = function (index, pShowLoading) {
        if (index === void 0) { index = 1; }
        if (pShowLoading === void 0) { pShowLoading = showInitLoading; }
        console.log('refresh called, isLoading: ', isLoadingData);
        if (isLoadingData) {
            return;
        }
        setIsLoadingData(true);
        if (index === 1 && pShowLoading) {
            console.log('setShowLoading(true) called');
            setShowLoading(true);
        }
        props
            .dataLoader({ index: index, size: size })
            .then(function (gjList) {
            var _a;
            if (!gjList.isOk()) {
                setShowError(true);
                setErrorType(ErrorType.SERVER);
            }
            else {
                setShowError(false);
                setIsFirstTimeLoadData(false);
                setNoMoreData(!gjList.hasMore());
                var newList = [];
                if (index !== 1) {
                    newList.push.apply(newList, (data !== null && data !== void 0 ? data : []));
                }
                newList.push.apply(newList, ((_a = gjList.data) !== null && _a !== void 0 ? _a : []));
                setData(newList);
                setPage(index);
            }
            setIsLoadingData(false);
            setShowLoading(false);
        })
            .catch(function (err) {
            console.error('err: ', err);
            setShowLoading(false);
            setShowError(true);
            setErrorType(ErrorType.NET);
            setIsLoadingData(false);
        });
    };
    useImperativeHandle(ref, function () { return ({
        refresh: function (pShowLoading) {
            loadData(1, pShowLoading);
        },
        changeData: function (changer) {
            setData(changer(data || []));
        },
    }); });
    var refresh = function () { return loadData(1); };
    // 这里在首页的时候为什么会调用两次？
    // 调用两次，说明控件被回收，又被创建了。
    useEffect(function () {
        refresh();
    }, [props.versionNum]);
    if (showError) {
        return <ErrorView errorType={errorType} onRefresh={refresh}/>;
    }
    if (dataIsEmpty) {
        return buildEmpty();
    }
    if (showLoading && isFirstTimeLoadData) {
        // noinspection JSSuspiciousNameCombination
        return (<View style={{
                alignItems: 'center',
                justifyContent: 'center',
                width: '100%',
                height: height,
            }}>
        <ActivityIndicator size={'large'} color={'green'}/>
      </View>);
    }
    var handleLoadMore = function () {
        if (noMoreData) {
            return;
        }
        loadData(page + 1);
    };
    var _LoadMoreIndicatorView = function () {
        if (noMoreData) {
            return null;
        }
        return (<View style={{
                height: gDp(100),
                alignItems: 'center',
                justifyContent: 'center',
            }}>
        <ActivityIndicator size={'small'}/>
      </View>);
    };
    return (<FlatList style={props.style} showsVerticalScrollIndicator={false} showsHorizontalScrollIndicator={false} {...props.flatListProps} contentContainerStyle={props.contentContainerStyle} data={data !== null && data !== void 0 ? data : []} renderItem={function (item) { return props.viewBuilder(item.item, item.index); }} refreshControl={(canRefresh && (<RefreshControl onRefresh={refresh} refreshing={false}/>)) ||
            undefined} ListFooterComponent={_LoadMoreIndicatorView} ItemSeparatorComponent={function () {
            return (<View style={{
                    height: dividerHeight,
                }}/>);
        }} onEndReached={handleLoadMore} onEndReachedThreshold={0.4}/>);
}
export default forwardRef(GJListView);
//# sourceMappingURL=LoadListView.js.map